# Recuperar VM com segurança
# Pelo ID gera dependência cíclica e, só pelo nome, pode gerar conflito
# O SCVMM permite mais de uma VM com o mesmo nome!
$VM = $null
$custom_agrupamento = Get-SCCustomProperty -VMMServer "{{ servidor_vmm }}" -Name "{{ campo_agrupamento }}"
$custom_nome_id = Get-SCCustomProperty -VMMServer "{{ servidor_vmm }}" -Name "{{ campo_id }}"
$nuvem = Get-SCCloud -VMMServer "{{ servidor_vmm }}" -Name "{{ nuvem }}"
$vms_nuvem = Get-SCVirtualMachine -VMMServer "{{ servidor_vmm }}" -Cloud $nuvem

foreach($vm_obj in $vms_nuvem) {
  $agrupamento = Get-SCCustomPropertyValue -InputObject $vm_obj -CustomProperty $custom_agrupamento
  if ($agrupamento.Value -eq "{{ agrupamento }}") {
    $nome_id = Get-SCCustomPropertyValue -InputObject $vm_obj -CustomProperty $custom_nome_id

    # Recuperando VM correta
    if ("{{ nome_vm }}" -eq $nome_id.Value){
        $VM = $vm_obj
    }
  }
}

$BusNumber = 0
$BusType = "{{ tipo }}"

# Definindo próximo LUN livre
$RangeLun = 0..1000
$LunsOcupados = @()
$LunsOcupados += $VM.VirtualDiskDrives | Where  {$_.BusType -eq $BusType -and $_.Bus -eq $BusNumber} | Select -ExpandProperty Lun
$LunsOcupados += $VM.VirtualDVDDrives | Where  {$_.BusType -eq $BusType -and $_.Bus -eq $BusNumber} | Select -ExpandProperty Lun
$LunsOcupados = $LunsOcupados | Sort Lun
$LunLivre = $RangeLun | Where-Object {$LunsOcupados -notcontains $_} | select -First 1

# Criando disco
New-SCVirtualDiskDrive -VMMServer "{{ servidor_vmm }}" -VM $VM -{{ tipo }} -Bus $BusNumber -LUN $LunLivre -VirtualHardDiskSizeMB {{ tamanho_mb }} -{{ tamanho_tipo }} -Filename "{{ arquivo }}" -VolumeType None {{ '-Path "' + caminho + '"' if caminho else '' }} -JobVariable "job" -RunAsynchronously | Out-Null

$Resultado = [PSCustomObject]@{
    Status = 'OK'
    Guid = $job.ID
}
ConvertTo-Json -Depth 3 $Resultado
